log

Function log 

pub fn log(string: &str)
Write logging information from the sanitizer runtime. The string is expected to be printable text with ā€˜\n’ ending each line. Timestamps and globally unique identifiers of the calling process and thread (zx::Koid) are attached to all messages, so there is no need to include those details in the text. The log of messages written with this call automatically includes address and ELF build ID details of the program and all shared libraries sufficient to translate raw address values into program symbols or source locations via a post-processor that has access to the original ELF files and their debugging information. The text can contain markup around address values that should be resolved symbolically.