take_bootstrap_channel

Function take_bootstrap_channel 

pub fn take_bootstrap_channel() -> Channel
This transfers ownership of the channel from the kernel where the message full of system handles can be read.