pub fn take_system_handles() -> Result<Vec<HandleInfo>, Status>Expand description
This reads the system capability message from the bootstrap channel. It is mutually exclusive with take_bootstrap_channel().
pub fn take_system_handles() -> Result<Vec<HandleInfo>, Status>This reads the system capability message from the bootstrap channel. It is mutually exclusive with take_bootstrap_channel().