pub struct Log { /* private fields */ }Expand description
This is an ephemeral object that implements the core::fmt::Write trait.
It’s used as write!(&zx_libc::sanitizer::Log::new(), "...", ...) to send
a single logging line. The object holds a fixed buffer that is used to
collect the multiple fragments from formatters; it’s written using
zx_libc::sanitizer::log() when the buffer fills or the object is dropped.
Implementations